macaulay2: System for computing in commutative algebra, algebraic geometry and related fields
=============================================================================================

Description
-----------

Macaulay2 is a system for computing in commutative algebra, algebraic geometry and related fields.


License
-------

GPL v2 or v3, see https://github.com/Macaulay2/M2/blob/master/M2/INSTALL


Upstream Contact
----------------

https://github.com/Macaulay2/M2
